← Back to team overview

widelands-dev team mailing list archive

[Merge] lp:~widelands-dev/widelands/string-fixes into lp:widelands

 

GunChleoc has proposed merging lp:~widelands-dev/widelands/string-fixes into lp:widelands.

Requested reviews:
  Widelands Developers (widelands-dev)
Related bugs:
  Bug #1421942 in widelands: "Unified term for "Black" and "Wasteland""
  https://bugs.launchpad.net/widelands/+bug/1421942
  Bug #1487887 in widelands: "Translation missing in editor and in replay tooltip"
  https://bugs.launchpad.net/widelands/+bug/1487887

For more details, see:
https://code.launchpad.net/~widelands-dev/widelands/string-fixes/+merge/277693

Various string fixes for issues reported on Transifex. Mostly for consistency with the recent terminology updates / disambiguation of strings.
-- 
Your team Widelands Developers is requested to review the proposed merge of lp:~widelands-dev/widelands/string-fixes into lp:widelands.
=== modified file 'campaigns/atl01.wmf/scripting/texts.lua'
--- campaigns/atl01.wmf/scripting/texts.lua	2015-10-31 12:11:44 +0000
+++ campaigns/atl01.wmf/scripting/texts.lua	2015-11-17 14:38:10 +0000
@@ -190,7 +190,7 @@
       title = _"Loftomor Speaks",
       body = loftomor(
          -- TRANSLATORS: Loftomor
-         _([[May Satul warm you, Jundlina! The most important things for building a settlement are the building materials. There are some trees here, so we should build housings for some woodcutters and of course also for foresters, so we will not run out of trees. Oh, and we mustn’t forget the sawmill, for most buildings can’t be made out of logs alone. Stronger buildings also need stone, but there is plenty to the north-east of here; we just need to build a quarry, and my stonemasons will go to work promptly.]]))
+         _([[May Satul warm you, Jundlina! The most important things for building a settlement are the building materials. There are some trees here, so we should build housings for some woodcutters and of course also for foresters, so we will not run out of trees. Oh, and we mustn’t forget the sawmill, for most buildings can’t be made out of logs alone. Stronger buildings also need granite, but there is plenty to the north-east of here; we just need to build a quarry, and my stonemasons will go to work promptly.]]))
          .. new_objectives(obj_ensure_build_wares_production)
    },
    {

=== modified file 'campaigns/bar01.wmf/scripting/texts.lua'
--- campaigns/bar01.wmf/scripting/texts.lua	2015-10-31 12:11:44 +0000
+++ campaigns/bar01.wmf/scripting/texts.lua	2015-11-17 14:38:10 +0000
@@ -113,7 +113,7 @@
    title = _"Build a lime kiln and coal economy",
    number = 3,
    body = objective_text(_"Build a lime kiln fed by a well, and by a charcoal kiln or by a coal mine",
-      _([[Better buildings may also require other improved materials besides blackwood. One of these is grout, which is produced out of raw stone, water and coal by a lime-burner.]])
+      _([[Better buildings may also require other improved materials besides blackwood. One of these is grout, which is produced out of granite, water and coal by a lime-burner.]])
       .. paragraphdivider() ..
       _([[You can obtain water by building a well upon a water source, which your geologists can discover when you send them to any flag that is not on a mountain.]])
       ..paragraphdivider() ..

=== modified file 'campaigns/emp01.wmf/scripting/texts.lua'
--- campaigns/emp01.wmf/scripting/texts.lua	2015-11-08 15:54:28 +0000
+++ campaigns/emp01.wmf/scripting/texts.lua	2015-11-17 14:38:10 +0000
@@ -64,7 +64,7 @@
    title=_"Build a quarry",
    number = 5,
    body = objective_text(_"Quarry",
-      listitem_bullet(_[[Build a quarry in the south to cut some stones and marble out of the rocks.]]) ..
+      listitem_bullet(_[[Build a quarry in the south to cut some granite and marble out of the rocks.]]) ..
       listitem_arrow(_[[These might be used for future buildings.]])
    ),
 }
@@ -201,7 +201,7 @@
    title=_"Thinking About the Future",
    body= saledus(_"Saledus notes…",
       -- TRANSLATORS: Saledus
-      _([[Sire, I just thought about the rocks standing on the south shore of this land. Perhaps we could cut out some useful hard stones and beautiful marble.]])
+      _([[Sire, I just thought about the rocks standing on the south shore of this land. Perhaps we could cut out some useful granite and beautiful marble.]])
       .. paragraphdivider() ..
       -- TRANSLATORS: Saledus
       _([[The repair of our ship will take a few weeks, anyway, and the resources we harvest now might be the base of strong and big buildings in another land.]]))
@@ -213,7 +213,7 @@
    title=_"A Step Forward",
    body= saledus(_"Saledus looks excited…",
       -- TRANSLATORS: Saledus
-      _([[Sire, today we got a lot closer to our first castle. The quarry to the south began its work today and will soon provide us with stones and beautiful marble.]])
+      _([[Sire, today we got a lot closer to our first castle. The quarry to the south began its work today and will soon provide us with granite and beautiful marble.]])
       .. paragraphdivider() ..
       -- TRANSLATORS: Saledus
       _([[Now we truly can look forward to settling down on another island.]])),

=== modified file 'campaigns/emp02.wmf/scripting/texts.lua'
--- campaigns/emp02.wmf/scripting/texts.lua	2015-10-31 12:11:44 +0000
+++ campaigns/emp02.wmf/scripting/texts.lua	2015-11-17 14:38:10 +0000
@@ -134,7 +134,7 @@
    posy = 1,
    body= lutius(_"Diary of Lutius",
       -- TRANSLATORS: Lutius - Diary
-      _([[Later, I walked down to the rocks in the south and looked for a place where we could build a quarry to get some hard stones for our larger buildings.]])
+      _([[Later, I walked down to the rocks in the south and looked for a place where we could build a quarry to get some granite for our larger buildings.]])
       .. paragraphdivider() ..
       -- TRANSLATORS: Lutius - Diary
       _([[Again, I felt like I was in paradise when I noticed that some marble-like stones were among the rocks. It seems that we will soon be able to build strong, luxurious buildings, like those we were accustomed to in Fremil.]]))

=== modified file 'campaigns/tutorial01_basic_control.wmf/scripting/texts.lua'
--- campaigns/tutorial01_basic_control.wmf/scripting/texts.lua	2015-11-07 08:28:27 +0000
+++ campaigns/tutorial01_basic_control.wmf/scripting/texts.lua	2015-11-17 14:38:10 +0000
@@ -350,7 +350,7 @@
 quarry_illegally_destroyed = {
    title = _"You Destroyed the Construction Site!",
    body = rt(
-      p(_[[It seems like you destroyed a construction site for a quarry we wanted to build. Since we need the stones, I suggest you reload the game from a previous savegame. Luckily, these are created from time to time. To do so, you have to go back to the main menu and choose ‘Single Player’ → ‘Load Game’. And please be a bit more careful next time.]])
+      p(_[[It seems like you destroyed a construction site for a quarry we wanted to build. Since we need the granite, I suggest you reload the game from a previous savegame. Luckily, these are created from time to time. To do so, you have to go back to the main menu and choose ‘Single Player’ → ‘Load Game’. And please be a bit more careful next time.]])
    ),
    w = 350,
    h = 250

=== modified file 'maps/Four Castles.wmf/elemental'
--- maps/Four Castles.wmf/elemental	2014-10-12 10:15:00 +0000
+++ maps/Four Castles.wmf/elemental	2015-11-17 14:38:10 +0000
@@ -6,7 +6,7 @@
 world=greenland
 name=_Four Castles
 author=Winterwind
-descr=_ "Well protected in their mighty fortresses, four power-hungry warlords are completing their schemes to dominate these lands..."
+descr=_ "Well protected in their mighty fortresses, four power-hungry warlords are completing their schemes to dominate these lands…"
 tags="official,ffa,2teams"
 
 [teams00]

=== modified file 'maps/Golden Peninsula.wmf/elemental'
--- maps/Golden Peninsula.wmf/elemental	2012-02-15 21:25:34 +0000
+++ maps/Golden Peninsula.wmf/elemental	2015-11-17 14:38:10 +0000
@@ -6,5 +6,5 @@
 world=greenland
 name=_Golden Peninsula
 author=Winterwind
-descr=_"Two empires race for the treasures of a legendary peninsula..."
+descr=_"Two empires race for the treasures of a legendary peninsula…"
 tags="official,1v1"

=== modified file 'maps/Lake of tranquility.wmf/elemental'
--- maps/Lake of tranquility.wmf/elemental	2014-02-25 10:47:47 +0000
+++ maps/Lake of tranquility.wmf/elemental	2015-11-17 14:38:10 +0000
@@ -6,5 +6,5 @@
 world=greenland
 name=_Lake of Tranquility
 author=Winterwind
-descr=_"This lake, deep in the most ancient forests, has long been known for its beauty and idyllic peace. However, its sanctity has been disturbed now, as two hostile tribes have arrived at its shores..."
+descr=_"This lake, deep in the most ancient forests, has long been known for its beauty and idyllic peace. However, its sanctity has been disturbed now, as two hostile tribes have arrived at its shores…"
 tags="official,1v1"

=== modified file 'maps/Last Bastion.wmf/elemental'
--- maps/Last Bastion.wmf/elemental	2014-02-25 10:47:47 +0000
+++ maps/Last Bastion.wmf/elemental	2015-11-17 14:38:10 +0000
@@ -8,5 +8,5 @@
 world="winterland"
 name=_ "Last Bastion"
 author="Another Barbarian"
-descr=_ "The whimsical Gods didn’t answer our prayers. Instead, the increasing sunlight heated up the Earth thousandfold and melted glaciers and people plunged into the deep. But now – high in the majestic mountains, on the last scrap of land – two surviving tribes are sheltering. Even though the Gods showed mercy and the climate thus turned cooler again, the water is still rising and rising. Onto the last secure place – the highest mountain range where the amount of gold and the space to live merely suffice for one tribe – only two opposite paths lead. But remember, be careful... this last living space is also a hard and small place to live. Don’t forget to take care of your timber supplies, you’ll need them."
+descr=_ "The whimsical Gods didn’t answer our prayers. Instead, the increasing sunlight heated up the Earth thousandfold and melted glaciers and people plunged into the deep. But now – high in the majestic mountains, on the last scrap of land – two surviving tribes are sheltering. Even though the Gods showed mercy and the climate thus turned cooler again, the water is still rising and rising. Onto the last secure place – the highest mountain range where the amount of gold and the space to live merely suffice for one tribe – only two opposite paths lead. But remember, be careful… this last living space is also a hard and small place to live. Don’t forget to take care of your timber supplies, you’ll need them."
 tags="official,1v1"

=== modified file 'maps/MP Scenarios/Island Hopping.wmf/scripting/texts.lua'
--- maps/MP Scenarios/Island Hopping.wmf/scripting/texts.lua	2015-10-31 12:11:44 +0000
+++ maps/MP Scenarios/Island Hopping.wmf/scripting/texts.lua	2015-11-17 14:38:10 +0000
@@ -20,7 +20,7 @@
 [[Whenever you finish an island, you will get bonus wares, depending on how many players ]] ..
 [[have finished the island before you. The earlier you finish, the fewer wares you will get. ]] ..
 [[See below for the details.]])) .. p(_(
-[[The point is that the first island only provides stones and wood, the second only meadows and resources. The economies you leave behind will continue to work for you, but you will only reap the benefits at the moment you reach a new island.]])
+[[The point is that the first island only provides rocks and trees, the second only meadows and resources. The economies you leave behind will continue to work for you, but you will only reap the benefits at the moment you reach a new island.]])
 ) ..
 p(_
 [[Finally, be careful not to waste your quartz and diamonds.]]

=== modified file 'maps/The Far North.wmf/elemental'
--- maps/The Far North.wmf/elemental	2012-02-15 21:25:34 +0000
+++ maps/The Far North.wmf/elemental	2015-11-17 14:38:10 +0000
@@ -8,5 +8,5 @@
 world="greenland"
 name=_ "The Far North"
 author="Another Barbarian"
-descr=_ "Some say that impenetrable lands to the far north scared away even the most courageous settlers and the bravest of the brave warriors. Big and old forests, full of big and predatory game, cut across by wetlands and hills were shrouded in mystery. The ones who had managed to come back mentioned tremendous buildings, decorated with carvings and gold from majestic mountain ranges somewhere amongst the wilderness. Dozens of years after only some crumbly ruins remain of these good old times, covered with moss and trees. Their shapes give only an idea about the craftsmanship of ancient constructors. Nobody knows why they (have) disappeared. Nobody knows why. People say that now nothing is blocking the road to wealth. But many will die pulled apart by wolves, engulfed by swamp... encircled by hostile tribes."
+descr=_ "Some say that impenetrable lands to the far north scared away even the most courageous settlers and the bravest of the brave warriors. Big and old forests, full of big and predatory game, cut across by wetlands and hills were shrouded in mystery. The ones who had managed to come back mentioned tremendous buildings, decorated with carvings and gold from majestic mountain ranges somewhere amongst the wilderness. Dozens of years after only some crumbly ruins remain of these good old times, covered with moss and trees. Their shapes give only an idea about the craftsmanship of ancient constructors. Nobody knows why they (have) disappeared. Nobody knows why. People say that now nothing is blocking the road to wealth. But many will die pulled apart by wolves, engulfed by swamp… encircled by hostile tribes."
 tags="official,1v1"

=== modified file 'maps/Together we're strong.wmf/elemental'
--- maps/Together we're strong.wmf/elemental	2014-02-25 10:47:47 +0000
+++ maps/Together we're strong.wmf/elemental	2015-11-17 14:38:10 +0000
@@ -8,5 +8,5 @@
 world="greenland"
 name=_"Together We’re Strong"
 author="Nasenbaer"
-descr=_"The four mighty harbors of the Craw Islands have been trading their goods among each other for ages. All of them needed resources that they could not produce in their own territory and in exchange provided other resources to those that could not produce them. Based on these trades, a very friendly commerce was common between the four harbors and the people living on the Craw Islands – until recently, when two of the harbors united to form an exclusive trade alliance, forcing the other two to do the same. Suddenly, it seems only a matter of time before the first fights between the harbors will shatter the peaceful life that has lasted for so long..."
+descr=_"The four mighty harbors of the Craw Islands have been trading their goods among each other for ages. All of them needed resources that they could not produce in their own territory and in exchange provided other resources to those that could not produce them. Based on these trades, a very friendly commerce was common between the four harbors and the people living on the Craw Islands – until recently, when two of the harbors united to form an exclusive trade alliance, forcing the other two to do the same. Suddenly, it seems only a matter of time before the first fights between the harbors will shatter the peaceful life that has lasted for so long…"
 tags="official,seafaring,1v1"

=== modified file 'scripting/formatting.lua'
--- scripting/formatting.lua	2015-10-31 12:11:44 +0000
+++ scripting/formatting.lua	2015-11-17 14:38:10 +0000
@@ -133,3 +133,13 @@
    return ("<p %s>"):format(opts) .. text .. "<br></p>" ..
       "<p font-size=8> <br></p>"
 end
+
+-- RST
+-- .. function:: a(text)
+--
+--    Underlines the text to show links. Only words with default paragraph text style.
+--
+--    :returns: Underlined text within a default paragraph
+function a(text)
+   return "</p><p font-size=12 font-decoration=underline>" .. text .. "</p><p font-size=12>"
+end

=== modified file 'src/wui/building_statistics_menu.cc'
--- tribes/buildings/productionsites/barbarians/goldmine/helptexts.lua	2015-11-08 11:49:22 +0000
+++ tribes/buildings/productionsites/barbarians/goldmine/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -1,6 +1,6 @@
 function building_helptext_lore()
    -- TRANSLATORS: Lore helptext for a building
-   return pgettext("barbarians_building", [[‘Soft and supple.<br> And yet untouched by time and weather.<br> Rays of sun, wrought into eternity ...’]])
+   return pgettext("barbarians_building", [[‘Soft and supple.<br> And yet untouched by time and weather.<br> Rays of sun, wrought into eternity…’]])
 end
 
 function building_helptext_lore_author()

=== modified file 'tribes/buildings/productionsites/barbarians/goldmine_deep/helptexts.lua'
--- tribes/buildings/productionsites/barbarians/goldmine_deep/helptexts.lua	2015-11-08 11:49:22 +0000
+++ tribes/buildings/productionsites/barbarians/goldmine_deep/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -1,6 +1,6 @@
 function building_helptext_lore()
    -- TRANSLATORS: Lore helptext for a building
-   return pgettext("barbarians_building", [[‘Soft and supple.<br> And yet untouched by time and weather.<br> Rays of sun, wrought into eternity ...’]])
+   return pgettext("barbarians_building", [[‘Soft and supple.<br> And yet untouched by time and weather.<br> Rays of sun, wrought into eternity…’]])
 end
 
 function building_helptext_lore_author()

=== modified file 'tribes/buildings/productionsites/barbarians/goldmine_deeper/helptexts.lua'
--- tribes/buildings/productionsites/barbarians/goldmine_deeper/helptexts.lua	2015-11-08 11:49:22 +0000
+++ tribes/buildings/productionsites/barbarians/goldmine_deeper/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -1,6 +1,6 @@
 function building_helptext_lore()
    -- TRANSLATORS: Lore helptext for a building
-   return pgettext("barbarians_building", [[‘Soft and supple.<br> And yet untouched by time and weather.<br> Rays of sun, wrought into eternity ...’]])
+   return pgettext("barbarians_building", [[‘Soft and supple.<br> And yet untouched by time and weather.<br> Rays of sun, wrought into eternity…’]])
 end
 
 function building_helptext_lore_author()

=== modified file 'tribes/buildings/productionsites/barbarians/wood_hardener/helptexts.lua'
--- tribes/buildings/productionsites/barbarians/wood_hardener/helptexts.lua	2015-11-08 13:59:37 +0000
+++ tribes/buildings/productionsites/barbarians/wood_hardener/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -13,7 +13,7 @@
 
 function building_helptext_purpose()
    -- TRANSLATORS: Purpose helptext for a building
-   return pgettext("barbarians_building", "Hardens wood by fire into blackwood, which is used to construct robust buildings.")
+   return pgettext("barbarians_building", "Hardens logs by fire into blackwood, which is used to construct robust buildings.")
 end
 
 function building_helptext_note()

=== modified file 'tribes/buildings/warehouses/atlanteans/warehouse/helptexts.lua'
--- tribes/buildings/warehouses/atlanteans/warehouse/helptexts.lua	2015-11-07 08:45:50 +0000
+++ tribes/buildings/warehouses/atlanteans/warehouse/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -13,7 +13,7 @@
 
 function building_helptext_purpose()
    -- TRANSLATORS: Purpose helptext for a building
-   return pgettext("atlanteans_building", "Stores soldiers, wares and tools.")
+   return pgettext("building", "Your workers and soldiers will find shelter here. Also stores your wares and tools.")
 end
 
 function building_helptext_note()

=== modified file 'tribes/buildings/warehouses/barbarians/warehouse/helptexts.lua'
--- tribes/buildings/warehouses/barbarians/warehouse/helptexts.lua	2015-11-07 08:45:50 +0000
+++ tribes/buildings/warehouses/barbarians/warehouse/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -13,7 +13,7 @@
 
 function building_helptext_purpose()
    -- TRANSLATORS: Purpose helptext for a building
-   return pgettext("barbarians_building", "Stores soldiers, wares and tools.")
+   return pgettext("building", "Your workers and soldiers will find shelter here. Also stores your wares and tools.")
 end
 
 function building_helptext_note()

=== modified file 'tribes/buildings/warehouses/empire/warehouse/helptexts.lua'
--- tribes/buildings/warehouses/empire/warehouse/helptexts.lua	2015-11-07 08:45:50 +0000
+++ tribes/buildings/warehouses/empire/warehouse/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -13,7 +13,7 @@
 
 function building_helptext_purpose()
    -- TRANSLATORS: Purpose helptext for a building
-   return pgettext("empire_building", "Stores soldiers, wares and tools.")
+   return pgettext("building", "Your workers and soldiers will find shelter here. Also stores your wares and tools.")
 end
 
 function building_helptext_note()

=== modified file 'tribes/wares/fire_tongs/helptexts.lua'
--- tribes/wares/fire_tongs/helptexts.lua	2015-11-04 08:33:24 +0000
+++ tribes/wares/fire_tongs/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -3,11 +3,11 @@
       -- TRANSLATORS: Helptext for a ware: Fire Tongs
       default = pgettext("ware", "Fire tongs are the tools of the smelter, who works in the smelting works."),
       -- TRANSLATORS: Helptext for a ware: Fire Tongs
-      atlanteans = pgettext("atlanteans_ware", "They are produced by the toolsmith."),
+      atlanteans = pgettext("atlanteans_ware_fire_tongs", "They are produced by the toolsmith."),
       -- TRANSLATORS: Helptext for a ware: Fire Tongs
       barbarians = pgettext("barbarians_ware", "Produced by the metal workshop (but they cease to be produced by the building if it is enhanced to an ax workshop and war mill)."),
       -- TRANSLATORS: Helptext for a ware: Fire Tongs
-      empire = pgettext("empire_ware", "They are produced by the toolsmith.")
+      empire = pgettext("empire_ware_fire_tongs", "They are produced by the toolsmith.")
    }
    local result = ""
    if tribe then

=== modified file 'tribes/wares/fishing_rod/helptexts.lua'
--- tribes/wares/fishing_rod/helptexts.lua	2015-10-31 12:11:44 +0000
+++ tribes/wares/fishing_rod/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -5,7 +5,7 @@
       -- TRANSLATORS: Helptext for a ware: Fishing Rod
       barbarians = pgettext("barbarians_ware", "They are one of the basic tools produced in a metal workshop (but cease to be produced by the building if it is enhanced to an ax workshop and war mill)."),
       -- TRANSLATORS: Helptext for a ware: Fishing Rod
-      empire = pgettext("empire_ware", "They are produced by the toolsmith.")
+      empire = pgettext("empire_ware_fishing_rod", "They are produced by the toolsmith.")
    }
    local result = ""
    if tribe then

=== modified file 'tribes/wares/hunting_spear/helptexts.lua'
--- tribes/wares/hunting_spear/helptexts.lua	2015-10-31 12:11:44 +0000
+++ tribes/wares/hunting_spear/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -5,7 +5,7 @@
       -- TRANSLATORS: Helptext for a ware: Hunting Spear
       barbarians = pgettext("barbarians_ware", "Hunting spears are produced in the metal workshop (but cease to be produced by the building if it is enhanced to an ax workshop and war mill)."),
       -- TRANSLATORS: Helptext for a ware: Hunting Spear
-      empire = pgettext("empire_ware", "They are produced by the toolsmith.")
+      empire = pgettext("empire_ware_hunting_spear", "They are produced by the toolsmith.")
    }
    local result = ""
    if tribe then

=== modified file 'tribes/wares/planks/helptexts.lua'
--- tribes/wares/planks/helptexts.lua	2015-10-31 12:11:44 +0000
+++ tribes/wares/planks/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -1,11 +1,15 @@
 function ware_helptext(tribe)
    local helptext = {
       -- TRANSLATORS: Helptext for a ware: Planks
-      default = pgettext("ware", "Planks are an important building material. They are produced out of logs by the sawmill."),
-      -- TRANSLATORS: Helptext for a ware: Planks
-      atlanteans = pgettext("atlanteans_ware", "The weapon smithy and the shipyard also use planks to produce the different tridents and mighty ships."),
-      -- TRANSLATORS: Helptext for a ware: Planks
-      empire = pgettext("empire_ware", "They are also used by the weapon smithy.")
+      default = pgettext("ware", "Planks are an important building material."),
+      -- TRANSLATORS: Helptext for a ware: Planks
+      atlanteans =
+			pgettext("atlanteans_ware_planks", "They are produced out of logs by the sawmill.") .. " " ..
+			pgettext("atlanteans_ware", "The weapon smithy and the shipyard also use planks to produce the different tridents and mighty ships."),
+      -- TRANSLATORS: Helptext for a ware: Planks
+      empire =
+			pgettext("empire_ware_planks", "They are produced out of logs by the sawmill.") .. " " ..
+			pgettext("empire_ware", "They are also used by the weapon smithy.")
    }
    local result = ""
    if tribe then

=== modified file 'tribes/workers/barbarians/lime_burner/helptexts.lua'
--- tribes/workers/barbarians/lime_burner/helptexts.lua	2015-10-31 12:11:44 +0000
+++ tribes/workers/barbarians/lime_burner/helptexts.lua	2015-11-17 14:38:10 +0000
@@ -1,4 +1,4 @@
 function worker_helptext()
    -- TRANSLATORS: Helptext for a worker: Lime-Burner
-   return pgettext("barbarians_worker", "Burns lime in the lime kiln.")
+   return pgettext("barbarians_worker", "Mixes grout out of granite, water and coal in the lime kiln.")
 end

=== modified file 'txts/README.lua'
--- txts/README.lua	2015-11-10 08:35:13 +0000
+++ txts/README.lua	2015-11-17 14:38:10 +0000
@@ -28,9 +28,9 @@
 tribes.]]
    ) .. h3(_
 [[Check out the Widelands project homepage:]]
-   ) .. p(
-[[http://wl.widelands.org]]
-   ) .. p(_
+   ) .. p(a(
+[[https://wl.widelands.org]]
+   )) .. p(_
 [[Widelands is licensed under the GNU General Public License (GPL). For more
 information, see the file ‘COPYING’.]]
    ) .. h3(_
@@ -79,7 +79,7 @@
 [[In the message window, the following additional shortcuts are available:]]
    ) .. p(
 _ "0: shows all messages" .. "<br>"
-.. _ "1: shows geologists' messages only" .. "<br>"
+.. _ "1: shows geologists’ messages only" .. "<br>"
 .. _ "2: shows economy messages only" .. "<br>"
 .. _ "3: shows seafaring messages only" .. "<br>"
 .. _ "4: shows warfare messages only" .. "<br>"
@@ -88,17 +88,15 @@
 .. _"DELETE: archives/restores the current message"
    ) .. h2(_
 [[Online Help]]
-   ) .. p( _
-[[If you need documentation or help for Widelands or the Widelands Editor, be
-sure to visit our homepage. You can find an up to date online help in our Wiki
-and a detailed description of the tribe economies in our online encyclopedia.]]
+   ) .. p(_"A detailed description of the tribes’ economies is available in the in-game Tribal Encyclopedia." .. " " ..
+(_[[If you need more documentation or help for Widelands or the Widelands Editor, be sure to visit our homepage at %s. You can find online help in our Wiki there.]]):bformat(a("https://wl.widelands.org/";))
    ) .. h2(_
 [[Reporting Bugs]]
    ) .. p(_
 [[If you encounter a bug, please report it to our bugtracker:]]
-   ) .. p(
+   ) .. p(a(
 [[https://bugs.launchpad.net/widelands]]
-   ) .. p(_
+   )) .. p(_
 [[Please provide enough background information. Tell us:]]
    ) .. p(_
 [[- Detailed steps on how to trigger the bug, if possible.]]

=== modified file 'txts/editor_readme.lua'
--- txts/editor_readme.lua	2015-10-31 12:11:44 +0000
+++ txts/editor_readme.lua	2015-11-17 14:38:10 +0000
@@ -2,10 +2,6 @@
 
 set_textdomain("texts")
 
-function a(text)
-   return "</p><p font-size=14 font-decoration=underline>" .. text
-end
-
 return {
    title = _"README for the Widelands Editor",
    text = rt(
@@ -13,9 +9,8 @@
 
       h1(_"Introduction") ..
 
-      p(_"This editor is intended for players who would like to design their own maps to use with Widelands. As you can see, this Editor is heavy work in progress and as the Editor becomes better and better, this text will also get longer and more complete.") ..
-      p(_"This Editor is intended for players who would like to design their own maps to use with Widelands.") ..
-      p(_"As you can see, this Editor is heavy work in progress and as the Editor becomes better and better, this text will also get longer and more complete.") ..
+      p(_"This editor is intended for players who would like to design their own maps to use with Widelands.") ..
+      p(_"As you can see, this editor is heavy work in progress and as the editor becomes better and better, this text will also get longer and more complete.") ..
       p(_"Please have a look at our enduser manuals on our wiki pages at: %s"):bformat(a("http://wl.widelands.org/wiki";)) ..
       p(_"Those pages might be more complete and up to date than this file, and you will also find a short tutorial about building a map there.") ..
 


Follow ups
--- src/wui/building_statistics_menu.cc	2015-11-11 09:53:54 +0000
+++ src/wui/building_statistics_menu.cc	2015-11-17 14:38:10 +0000
@@ -91,16 +91,16 @@
 		unproductive_label_(
 			&unproductive_box_,
 			/** TRANSLATORS: This is the first part of productivity with input field */
-			/** TRANSLATORS: Building statistics window -  'Low Production: <input>%' */
-			_("Low Production: "),
+			/** TRANSLATORS: Building statistics window - 'Low Productivity <input>%:' */
+			_("Low Productivity "),
 			UI::Align_BottomLeft),
 		unproductive_percent_(
 			&unproductive_box_, 0, 0, 35, kLabelHeight, g_gr->images().get("pics/but1.png")),
 		unproductive_label2_(
 			&unproductive_box_,
 			/** TRANSLATORS: This is the second part of productivity with input field */
-			/** TRANSLATORS: Building statistics window -  'Low Production: <input>%' */
-			_("%"),
+			/** TRANSLATORS: Building statistics window -  'Low Productivity <input>%:' */
+			_("%:"),
 			UI::Align_BottomLeft),
 		no_owned_label_(&navigation_panel_,
 							 get_inner_w() - 2 * kButtonRowHeight - kMargin,
@@ -271,6 +271,7 @@
 	unproductive_percent_.set_max_length(4);
 	unproductive_label2_.set_size(unproductive_label2_.get_w(), kButtonRowHeight);
 	unproductive_box_.add(&unproductive_label_, UI::Align_Left);
+	unproductive_box_.add_space(2);
 	unproductive_box_.add(&unproductive_percent_, UI::Align_Left);
 	unproductive_box_.add(&unproductive_label2_, UI::Align_Left);
 	unproductive_box_.set_size(
@@ -688,7 +689,7 @@
 																											0);
 				navigation_buttons_[NavigationButton::NextUnproductive]->set_visible(true);
 				navigation_buttons_[NavigationButton::PrevUnproductive]->set_visible(true);
-				unproductive_label_.set_text(_("Low Production: "));
+				unproductive_label_.set_text(_("Low Productivity "));
 				unproductive_box_.set_visible(true);
 				unproductive_label_.set_visible(true);
 				unproductive_percent_.set_visible(true);

=== modified file 'tribes/buildings/productionsites/barbarians/goldmine/helptexts.lua'